# -*- coding: utf-8 -*-

import os, sys
# ensure citruleaf.py is in path
sys.path.insert(1, os.path.realpath( os.pardir ) )

import unittest
import citrusleaf as cl

class TestReplaceRoles(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        
        cls.cluster_with_user_admin = cl.CitrusleafCluster()
        cls.cluster_with_user_admin.setUser('testuauser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_user_admin, 'localhost', '3000')

        cls.cluster_with_read_user = cl.CitrusleafCluster()
        cls.cluster_with_read_user.setUser('testreaduser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_read_user, 'localhost', '3000')
    
    @classmethod
    def tearDownClass(cls):

        del(cls.cluster_with_user_admin)
        del(cls.cluster_with_read_user)

    def test_replaceRoles(self):

        status = cl.replaceRoles(TestReplaceRoles.cluster_with_user_admin, 'testsauser', roles=['user-admin'])

        self.assertEqual(0, status)

        status = cl.replaceRoles(TestReplaceRoles.cluster_with_user_admin, 'testsauser', roles=['sys-admin'])

        self.assertEqual(0, status)

    def test_replaceRoles_for_non_existent_user(self):

        status = cl.replaceRoles(TestReplaceRoles.cluster_with_user_admin, 'testuser', roles=['user-admin'])

        self.assertEqual(60, status)

    def test_replaceRoles_for_invalid_roles(self):

        status = cl.replaceRoles(TestReplaceRoles.cluster_with_user_admin, 'testsauser', roles=['viewer-role'])

        self.assertEqual(70, status)

    def test_replaceRoles_with_other_than_useradmin_user(self):

        status = cl.replaceRoles(TestReplaceRoles.cluster_with_read_user, 'testsauser', roles=['user-admin'])

        self.assertEqual(81, status)


if __name__ == "__main__":
    unittest.main()
